@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"lookahead_8h.html#aa177b3848c3b2d840eeb7060e5f163dd":[14,0,2,2,10,7],
 "lookahead_8h.html#af061d48eaecd02d50cf646e84426aca1":[14,0,2,2,10,1],
 "lookahead_8h_source.html":[14,0,2,2,10],
 "modules.html":[12],
@@ -125,35 +126,34 @@ var NAVTREEINDEX4 =
 "structCB__COEFF__BUFFER.html#a67894d997256030d9357a997a0a68da9":[13,0,40,2],
 "structCB__COEFF__BUFFER.html#a7c8fd243688fcb9d8039a8dbc3b90499":[13,0,40,1],
 "structCB__COEFF__BUFFER.html#ab46d9c426ce409bd819e8e85707550bc":[13,0,40,0],
-"structCOMP__RD__STATS.html":[13,0,49],
-"structCOMP__RD__STATS.html#a0180a3d9fe639a244d2f0f4e7ab015db":[13,0,49,3],
-"structCOMP__RD__STATS.html#a21781d988675fd14d2476fe18a66ea2c":[13,0,49,8],
-"structCOMP__RD__STATS.html#a2e458dbc4ea99b9af00d73524408bcaf":[13,0,49,4],
-"structCOMP__RD__STATS.html#a3ca315bd64b98d43a8e4cfe9fa351248":[13,0,49,11],
-"structCOMP__RD__STATS.html#a4452b7387196bb4c689b8568b7595598":[13,0,49,1],
-"structCOMP__RD__STATS.html#a483c89ae8f480b8315056c9c2fffc935":[13,0,49,7],
-"structCOMP__RD__STATS.html#a4d3a8cd6d01bcbddca9e6be35791ed9c":[13,0,49,10],
-"structCOMP__RD__STATS.html#a595385f4435ba53b0a4cddc7f2406a01":[13,0,49,0],
-"structCOMP__RD__STATS.html#a901af9a52d332d23c0e63f5096dc6b86":[13,0,49,5],
-"structCOMP__RD__STATS.html#a9606c8d33733cefddf418a0b7a4bd7e6":[13,0,49,6],
-"structCOMP__RD__STATS.html#a961a8e50b2c1260936f4a44c87ed348f":[13,0,49,2],
-"structCOMP__RD__STATS.html#ac969603c69501775a83c07d25772d9db":[13,0,49,9],
+"structCOMP__RD__STATS.html":[13,0,50],
+"structCOMP__RD__STATS.html#a0180a3d9fe639a244d2f0f4e7ab015db":[13,0,50,3],
+"structCOMP__RD__STATS.html#a21781d988675fd14d2476fe18a66ea2c":[13,0,50,8],
+"structCOMP__RD__STATS.html#a2e458dbc4ea99b9af00d73524408bcaf":[13,0,50,4],
+"structCOMP__RD__STATS.html#a3ca315bd64b98d43a8e4cfe9fa351248":[13,0,50,11],
+"structCOMP__RD__STATS.html#a4452b7387196bb4c689b8568b7595598":[13,0,50,1],
+"structCOMP__RD__STATS.html#a483c89ae8f480b8315056c9c2fffc935":[13,0,50,7],
+"structCOMP__RD__STATS.html#a4d3a8cd6d01bcbddca9e6be35791ed9c":[13,0,50,10],
+"structCOMP__RD__STATS.html#a595385f4435ba53b0a4cddc7f2406a01":[13,0,50,0],
+"structCOMP__RD__STATS.html#a901af9a52d332d23c0e63f5096dc6b86":[13,0,50,5],
+"structCOMP__RD__STATS.html#a9606c8d33733cefddf418a0b7a4bd7e6":[13,0,50,6],
+"structCOMP__RD__STATS.html#a961a8e50b2c1260936f4a44c87ed348f":[13,0,50,2],
+"structCOMP__RD__STATS.html#ac969603c69501775a83c07d25772d9db":[13,0,50,9],
 "structCYCLIC__REFRESH.html":[12,2,9,0],
-"structCYCLIC__REFRESH.html#a08162f2bd6028160d470024577dfcec6":[12,2,9,0,12],
-"structCYCLIC__REFRESH.html#a11f1a950d76b9908606d234eab0d8b2b":[12,2,9,0,10],
+"structCYCLIC__REFRESH.html#a08162f2bd6028160d470024577dfcec6":[12,2,9,0,11],
+"structCYCLIC__REFRESH.html#a11f1a950d76b9908606d234eab0d8b2b":[12,2,9,0,9],
 "structCYCLIC__REFRESH.html#a14a2e1c9b9ca6a36bb29ccd9a0e02002":[12,2,9,0,3],
 "structCYCLIC__REFRESH.html#a383b90c4a87340a91580aac8a537aee6":[12,2,9,0,7],
 "structCYCLIC__REFRESH.html#a441d4805353c603874ae7f356a649cd3":[12,2,9,0,1],
-"structCYCLIC__REFRESH.html#a5034d2e9cba349dd451d41f6362dc6f9":[12,2,9,0,9],
-"structCYCLIC__REFRESH.html#a68abf0fd3f8b6d9c3bd9725e71f19fe1":[12,2,9,0,8],
-"structCYCLIC__REFRESH.html#a74276b39125b068743f0b6dc2ba0f36a":[12,2,9,0,11],
+"structCYCLIC__REFRESH.html#a5034d2e9cba349dd451d41f6362dc6f9":[12,2,9,0,8],
+"structCYCLIC__REFRESH.html#a74276b39125b068743f0b6dc2ba0f36a":[12,2,9,0,10],
 "structCYCLIC__REFRESH.html#a7b30c416581337161479c00e08fed8ea":[12,2,9,0,6],
 "structCYCLIC__REFRESH.html#ac79bf4f50ebef3b6e6fd91e25af9a2c6":[12,2,9,0,4],
 "structCYCLIC__REFRESH.html#ad45cfe66fc5d1ab8aecee9bc1ef72f44":[12,2,9,0,2],
-"structCYCLIC__REFRESH.html#ae0966dda4b2470d422129ed473e39d4c":[12,2,9,0,14],
+"structCYCLIC__REFRESH.html#ae0966dda4b2470d422129ed473e39d4c":[12,2,9,0,13],
 "structCYCLIC__REFRESH.html#ae315bcaf369b95ab1162f2d1271263de":[12,2,9,0,0],
 "structCYCLIC__REFRESH.html#aebf6363e9a037324981bd3739cdce960":[12,2,9,0,5],
-"structCYCLIC__REFRESH.html#afe7bf45e2c31665d7d64254c23fdaf6c":[12,2,9,0,13],
+"structCYCLIC__REFRESH.html#afe7bf45e2c31665d7d64254c23fdaf6c":[12,2,9,0,12],
 "structCdefBlockInfo.html":[13,0,41],
 "structCdefBlockInfo.html#a02095b6a7c1fa710fba74e8f9562e7a2":[13,0,41,9],
 "structCdefBlockInfo.html#a03652fa705d9a4958a854e15c235ba78":[13,0,41,14],
@@ -192,62 +192,62 @@ var NAVTREEINDEX4 =
 "structCoeffCosts.html":[13,0,44],
 "structCoeffCosts.html#ae8afc618945a082c26412e9c1e90fbde":[13,0,44,1],
 "structCoeffCosts.html#af990465822bc644c743c5129d8d6d039":[13,0,44,0],
-"structCommonContexts.html":[13,0,45],
-"structCommonContexts.html#a065431a5259fddc51bceec4f22233419":[13,0,45,0],
-"structCommonContexts.html#a1a56ca1f3a6aac2c924b2cbba039646a":[13,0,45,3],
-"structCommonContexts.html#a8d9c8b0840bdb4969f101ad6eb124c2f":[13,0,45,1],
-"structCommonContexts.html#aae9be789112f0df7ba36a3eec9d5638a":[13,0,45,4],
-"structCommonContexts.html#aded39732de8b98e105ddcb3b71658fdc":[13,0,45,5],
-"structCommonContexts.html#af17097fb0b2d4a6d13cf59b423251d4a":[13,0,45,2],
-"structCommonModeInfoParams.html":[13,0,46],
-"structCommonModeInfoParams.html#a40d91737a1845d3f1b97453e5f07c165":[13,0,46,1],
-"structCommonModeInfoParams.html#a4291187795b4cea68b5f929d4d1fb38a":[13,0,46,5],
-"structCommonModeInfoParams.html#a44afb91e26f556fb0056534e2a86baa9":[13,0,46,3],
-"structCommonModeInfoParams.html#a4cdc385f2d2cad290f7f6a8ce2bc13b2":[13,0,46,14],
-"structCommonModeInfoParams.html#a53fac1021e425da3597458811d265338":[13,0,46,13],
-"structCommonModeInfoParams.html#a5cc1ec6f5bab71ce47cc47bf89d8fe8b":[13,0,46,4],
-"structCommonModeInfoParams.html#a6dc490e2163ec659c201e4cde1c0bfff":[13,0,46,6],
-"structCommonModeInfoParams.html#a715f2b0431a451bcda33619e62be23f9":[13,0,46,15],
-"structCommonModeInfoParams.html#a8495d6fc859170905ae3d74e7935710d":[13,0,46,2],
-"structCommonModeInfoParams.html#a93a0a944c05c5142a928085dc6665308":[13,0,46,12],
-"structCommonModeInfoParams.html#ace029a6440830efcea0204384cd68cab":[13,0,46,7],
-"structCommonModeInfoParams.html#ad4cb15e10cc730ab925ac3a3ba142c45":[13,0,46,10],
-"structCommonModeInfoParams.html#ada12fea8f2e30e7a0ea06ccb381c6ee8":[13,0,46,11],
-"structCommonModeInfoParams.html#ae4ec94f26ebdbe07d76700e3a33fae78":[13,0,46,0],
-"structCommonModeInfoParams.html#ae9e5d24e6af7f50d83d89bba2f95c332":[13,0,46,9],
-"structCommonModeInfoParams.html#af433ad72e0ce77b148f933667a815650":[13,0,46,8],
-"structCommonQuantParams.html":[13,0,47],
-"structCommonQuantParams.html#a01d6e6e663e708fd230dfa8a4d771320":[13,0,47,4],
-"structCommonQuantParams.html#a0bec28af02aa55ca9f2d44e212fff445":[13,0,47,12],
-"structCommonQuantParams.html#a184dcbe8f484a0d1d224f367224a5379":[13,0,47,17],
-"structCommonQuantParams.html#a2ad05f39cabcdd12d9bd34136788793a":[13,0,47,9],
-"structCommonQuantParams.html#a357284012595df64bd5d687fa667825e":[13,0,47,7],
-"structCommonQuantParams.html#a4f9755f8ced8ec35d3dc0986c4c3ce3b":[13,0,47,11],
-"structCommonQuantParams.html#a5285812982f35c7324e2a071bde7baad":[13,0,47,15],
-"structCommonQuantParams.html#a5770765a82200e84a9e621f1632b3f5d":[13,0,47,5],
-"structCommonQuantParams.html#a5a12ee629649c8c1958238cd238b36bc":[13,0,47,14],
-"structCommonQuantParams.html#a6825895b20499860191f94b908be2f39":[13,0,47,2],
-"structCommonQuantParams.html#a69949db8cd0b812e3c8485e0585d6da2":[13,0,47,16],
-"structCommonQuantParams.html#a7a9038020ad4b2a837f75c964e9cbd40":[13,0,47,0],
-"structCommonQuantParams.html#a966913d34df3a5909feb612e714bd6b3":[13,0,47,8],
-"structCommonQuantParams.html#aaeafbb83ee5df9c8fbba96f3cd250338":[13,0,47,13],
-"structCommonQuantParams.html#ad5a34dbb0ead83ec6d2ef1a598ed832d":[13,0,47,6],
-"structCommonQuantParams.html#ade3a29210ea7504fcba1c4bcacd1e692":[13,0,47,3],
-"structCommonQuantParams.html#ae6b10a492cbf8dd0501129c7d264ee6d":[13,0,47,1],
-"structCommonQuantParams.html#afae3f12fc3aa940840f9a04b05fdd387":[13,0,47,10],
-"structCommonTileParams.html":[13,0,48],
-"structCommonTileParams.html#a001b6543ac7a848ede198dc1ff7e4a28":[13,0,48,5],
-"structCommonTileParams.html#a1141ae4079cca997c2cdd98e7eeca115":[13,0,48,2],
-"structCommonTileParams.html#a30ee31c09c895fe2a590359e197b85c5":[13,0,48,7],
-"structCommonTileParams.html#a32574d672c09b5b98a4ae9d3645c980b":[13,0,48,11],
-"structCommonTileParams.html#a44b107256e3a2e527c5d47b74af43951":[13,0,48,8],
-"structCommonTileParams.html#a5f6b00965abc83409350b6c77169fbbb":[13,0,48,13],
-"structCommonTileParams.html#a68c8e416df2344d1338ebc6959651b0d":[13,0,48,16],
-"structCommonTileParams.html#a8842e296add2a242e4aaf0fcae574f9b":[13,0,48,0],
-"structCommonTileParams.html#a9d06ed0c420a1571838df00f89603ba7":[13,0,48,3],
-"structCommonTileParams.html#aa268beca2c5cb66be43cf6f9ab3d81fd":[13,0,48,17],
-"structCommonTileParams.html#ab00658e6a613f237ebe25cd533da2f2b":[13,0,48,18],
-"structCommonTileParams.html#ac9c29974db76e6d01bbe23be00487613":[13,0,48,12],
-"structCommonTileParams.html#ad8043d38fd14939030a7b120e4804f08":[13,0,48,6],
-"structCommonTileParams.html#adf531cc5778117db62b32d0c535a5ce5":[13,0,48,14]
+"structColorCount.html":[13,0,45],
+"structColorCount.html#a1732c20ac192fe0d777f1d8502f2ceeb":[13,0,45,1],
+"structColorCount.html#ac569609b9a11dbe3915915d1e2def8d4":[13,0,45,0],
+"structCommonContexts.html":[13,0,46],
+"structCommonContexts.html#a065431a5259fddc51bceec4f22233419":[13,0,46,0],
+"structCommonContexts.html#a1a56ca1f3a6aac2c924b2cbba039646a":[13,0,46,3],
+"structCommonContexts.html#a8d9c8b0840bdb4969f101ad6eb124c2f":[13,0,46,1],
+"structCommonContexts.html#aae9be789112f0df7ba36a3eec9d5638a":[13,0,46,4],
+"structCommonContexts.html#aded39732de8b98e105ddcb3b71658fdc":[13,0,46,5],
+"structCommonContexts.html#af17097fb0b2d4a6d13cf59b423251d4a":[13,0,46,2],
+"structCommonModeInfoParams.html":[13,0,47],
+"structCommonModeInfoParams.html#a40d91737a1845d3f1b97453e5f07c165":[13,0,47,1],
+"structCommonModeInfoParams.html#a4291187795b4cea68b5f929d4d1fb38a":[13,0,47,5],
+"structCommonModeInfoParams.html#a44afb91e26f556fb0056534e2a86baa9":[13,0,47,3],
+"structCommonModeInfoParams.html#a4cdc385f2d2cad290f7f6a8ce2bc13b2":[13,0,47,14],
+"structCommonModeInfoParams.html#a53fac1021e425da3597458811d265338":[13,0,47,13],
+"structCommonModeInfoParams.html#a5cc1ec6f5bab71ce47cc47bf89d8fe8b":[13,0,47,4],
+"structCommonModeInfoParams.html#a6dc490e2163ec659c201e4cde1c0bfff":[13,0,47,6],
+"structCommonModeInfoParams.html#a715f2b0431a451bcda33619e62be23f9":[13,0,47,15],
+"structCommonModeInfoParams.html#a8495d6fc859170905ae3d74e7935710d":[13,0,47,2],
+"structCommonModeInfoParams.html#a93a0a944c05c5142a928085dc6665308":[13,0,47,12],
+"structCommonModeInfoParams.html#ace029a6440830efcea0204384cd68cab":[13,0,47,7],
+"structCommonModeInfoParams.html#ad4cb15e10cc730ab925ac3a3ba142c45":[13,0,47,10],
+"structCommonModeInfoParams.html#ada12fea8f2e30e7a0ea06ccb381c6ee8":[13,0,47,11],
+"structCommonModeInfoParams.html#ae4ec94f26ebdbe07d76700e3a33fae78":[13,0,47,0],
+"structCommonModeInfoParams.html#ae9e5d24e6af7f50d83d89bba2f95c332":[13,0,47,9],
+"structCommonModeInfoParams.html#af433ad72e0ce77b148f933667a815650":[13,0,47,8],
+"structCommonQuantParams.html":[13,0,48],
+"structCommonQuantParams.html#a01d6e6e663e708fd230dfa8a4d771320":[13,0,48,4],
+"structCommonQuantParams.html#a0bec28af02aa55ca9f2d44e212fff445":[13,0,48,12],
+"structCommonQuantParams.html#a184dcbe8f484a0d1d224f367224a5379":[13,0,48,17],
+"structCommonQuantParams.html#a2ad05f39cabcdd12d9bd34136788793a":[13,0,48,9],
+"structCommonQuantParams.html#a357284012595df64bd5d687fa667825e":[13,0,48,7],
+"structCommonQuantParams.html#a4f9755f8ced8ec35d3dc0986c4c3ce3b":[13,0,48,11],
+"structCommonQuantParams.html#a5285812982f35c7324e2a071bde7baad":[13,0,48,15],
+"structCommonQuantParams.html#a5770765a82200e84a9e621f1632b3f5d":[13,0,48,5],
+"structCommonQuantParams.html#a5a12ee629649c8c1958238cd238b36bc":[13,0,48,14],
+"structCommonQuantParams.html#a6825895b20499860191f94b908be2f39":[13,0,48,2],
+"structCommonQuantParams.html#a69949db8cd0b812e3c8485e0585d6da2":[13,0,48,16],
+"structCommonQuantParams.html#a7a9038020ad4b2a837f75c964e9cbd40":[13,0,48,0],
+"structCommonQuantParams.html#a966913d34df3a5909feb612e714bd6b3":[13,0,48,8],
+"structCommonQuantParams.html#aaeafbb83ee5df9c8fbba96f3cd250338":[13,0,48,13],
+"structCommonQuantParams.html#ad5a34dbb0ead83ec6d2ef1a598ed832d":[13,0,48,6],
+"structCommonQuantParams.html#ade3a29210ea7504fcba1c4bcacd1e692":[13,0,48,3],
+"structCommonQuantParams.html#ae6b10a492cbf8dd0501129c7d264ee6d":[13,0,48,1],
+"structCommonQuantParams.html#afae3f12fc3aa940840f9a04b05fdd387":[13,0,48,10],
+"structCommonTileParams.html":[13,0,49],
+"structCommonTileParams.html#a001b6543ac7a848ede198dc1ff7e4a28":[13,0,49,5],
+"structCommonTileParams.html#a1141ae4079cca997c2cdd98e7eeca115":[13,0,49,2],
+"structCommonTileParams.html#a30ee31c09c895fe2a590359e197b85c5":[13,0,49,7],
+"structCommonTileParams.html#a32574d672c09b5b98a4ae9d3645c980b":[13,0,49,11],
+"structCommonTileParams.html#a44b107256e3a2e527c5d47b74af43951":[13,0,49,8],
+"structCommonTileParams.html#a5f6b00965abc83409350b6c77169fbbb":[13,0,49,13],
+"structCommonTileParams.html#a68c8e416df2344d1338ebc6959651b0d":[13,0,49,16],
+"structCommonTileParams.html#a8842e296add2a242e4aaf0fcae574f9b":[13,0,49,0],
+"structCommonTileParams.html#a9d06ed0c420a1571838df00f89603ba7":[13,0,49,3],
+"structCommonTileParams.html#aa268beca2c5cb66be43cf6f9ab3d81fd":[13,0,49,17],
+"structCommonTileParams.html#ab00658e6a613f237ebe25cd533da2f2b":[13,0,49,18]
 };
